from pysmiles import read_smiles

from smilestats import methylene_group_count


def test_zero_methylene_group_count():
    molecule = read_smiles('Cc1cc(O)ccc1O')
    assert methylene_group_count(molecule) == 0


def test_one_methylene_group_count():
    molecule = read_smiles('Oc1cccc(Cc2ccccc2)c1')
    assert methylene_group_count(molecule) == 1


def test_two_methylene_group_count():
    molecule = read_smiles('Oc1cccc(CCc2cc(O)cc(O)c2)c1')
    assert methylene_group_count(molecule) == 2



from pysmiles import read_smiles

from smilestats import aromatic_ring_count


def test_one_aromatic_ring():
    molecule = read_smiles('Cc1cc(O)ccc1O')
    assert aromatic_ring_count(molecule) == 1


def test_two_aromatic_ring():
    molecule = read_smiles('Cc1cc(-c2cccc(Cl)c2)ccc1O')
    assert aromatic_ring_count(molecule) == 2



from pysmiles import read_smiles

from smilestats import methyl_group_count


def test_zero_methyl_group_count():
    molecule = read_smiles('Oc1ccc(Cl)cc1Cl')
    assert methyl_group_count(molecule) == 0


def test_one_methyl_group_count():
    molecule = read_smiles('Cc1cc(O)ccc1O')
    assert methyl_group_count(molecule) == 1


def test_two_methyl_group_count():
    molecule = read_smiles('Cc1ccc(O)c(C)c1')
    assert methyl_group_count(molecule) == 2



from pysmiles import read_smiles

from smilestats import hydroxy_group_count


def test_one_hydroxy_group():
    molecule = read_smiles('Cc1cc(-c2cccc(Cl)c2)ccc1O')
    assert hydroxy_group_count(molecule) == 1


def test_two_hydroxy_group():
    molecule = read_smiles('Cc1cc(O)ccc1O')
    assert hydroxy_group_count(molecule) == 2
